nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

DmaFinAddr

Struct DmaFinAddr 

#[repr(transparent)]
pub struct DmaFinAddr(pub u32);
Final DMA Address

Tuple Fields

0: u32

Implementations

Source

impl DmaFinAddr

pub const fn dma_fin_addr(&self) -> u32

Indicates the final address of system memory that was accessed by ELS during the last command.

pub const fn set_dma_fin_addr(&mut self, val: u32)

Indicates the final address of system memory that was accessed by ELS during the last command.