nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

DmaRes0

Struct DmaRes0 

#[repr(transparent)]
pub struct DmaRes0(pub u32);
DMA Result 0

Tuple Fields

0: u32

Implementations

Source

impl DmaRes0

pub const fn addr_res0(&self) -> u32

Defines the system start address where the result of the ELS operation is transferred via DMA.

pub const fn set_addr_res0(&mut self, val: u32)

Defines the system start address where the result of the ELS operation is transferred via DMA.