nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

DmaRes0Len

Struct DmaRes0Len 

#[repr(transparent)]
pub struct DmaRes0Len(pub u32);
DMA Result 0 Length

Tuple Fields

0: u32

Implementations

Source

impl DmaRes0Len

pub const fn size_res0_len(&self) -> u32

Size in bytes of the data to be transferred

pub const fn set_size_res0_len(&mut self, val: u32)

Size in bytes of the data to be transferred