nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

DmaSrc0Len

Struct DmaSrc0Len 

#[repr(transparent)]
pub struct DmaSrc0Len(pub u32);
DMA Source 0 Length

Tuple Fields

0: u32

Implementations

Source

impl DmaSrc0Len

pub const fn size_src0_len(&self) -> u32

Size in bytes of the data to be transferred from the target defined in SFR DMA_SRC0.

pub const fn set_size_src0_len(&mut self, val: u32)

Size in bytes of the data to be transferred from the target defined in SFR DMA_SRC0.