nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

DmaSrc2

Struct DmaSrc2 

#[repr(transparent)]
pub struct DmaSrc2(pub u32);
DMA Source 2

Tuple Fields

0: u32

Implementations

Source

impl DmaSrc2

pub const fn addr_src2(&self) -> u32

Defines the system address of the start of the data to be transferred to the ELS via DMA.

pub const fn set_addr_src2(&mut self, val: u32)

Defines the system address of the start of the data to be transferred to the ELS via DMA.