#[repr(transparent)]pub struct DmaSrc2Len(pub u32);Expand description
DMA Source 2 Length
Tuple Fields
0: u32Implementations
Sourceimpl DmaSrc2Len
impl DmaSrc2Len
Sourcepub const fn size_src2_len(&self) -> u32
pub const fn size_src2_len(&self) -> u32
Size in bytes of the data to be transferred from the target defined in SFR DMA_SRC2.
Sourcepub const fn set_size_src2_len(&mut self, val: u32)
pub const fn set_size_src2_len(&mut self, val: u32)
Size in bytes of the data to be transferred from the target defined in SFR DMA_SRC2.