nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

Kpropin

Struct Kpropin 

#[repr(transparent)]
pub struct Kpropin(pub u32);
Key Properties Request

Tuple Fields

0: u32

Implementations

Source

impl Kpropin

pub const fn kpropin(&self) -> u32

Specifies requested properties of the key created by ELS command.

pub const fn set_kpropin(&mut self, val: u32)

Specifies requested properties of the key created by ELS command.