#[repr(transparent)]pub struct DmaFinAddr(pub u32);Expand description
Final DMA Address
Tuple Fields
0: u32Implementations
Sourceimpl DmaFinAddr
impl DmaFinAddr
Sourcepub const fn dma_fin_addr(&self) -> u32
pub const fn dma_fin_addr(&self) -> u32
Indicates the final address of system memory that was accessed by ELS during the last command.
Sourcepub const fn set_dma_fin_addr(&mut self, val: u32)
pub const fn set_dma_fin_addr(&mut self, val: u32)
Indicates the final address of system memory that was accessed by ELS during the last command.