#[repr(transparent)]pub struct ErrStatus(pub u32);Expand description
Error Status
Tuple Fields
0: u32Implementations
Sourceimpl ErrStatus
impl ErrStatus
Sourcepub const fn set_bus_err(&mut self, val: bool)
pub const fn set_bus_err(&mut self, val: bool)
Indicates public or private bus access error.
Sourcepub const fn opn_err(&self) -> bool
pub const fn opn_err(&self) -> bool
Indicates operational error, that is, ELS has been incorrectly operated.
Sourcepub const fn set_opn_err(&mut self, val: bool)
pub const fn set_opn_err(&mut self, val: bool)
Indicates operational error, that is, ELS has been incorrectly operated.
Sourcepub const fn alg_err(&self) -> bool
pub const fn alg_err(&self) -> bool
Indicates algorithm error; an internal algorithm has produced an unexpected result.
Sourcepub const fn set_alg_err(&mut self, val: bool)
pub const fn set_alg_err(&mut self, val: bool)
Indicates algorithm error; an internal algorithm has produced an unexpected result.
Sourcepub const fn itg_err(&self) -> bool
pub const fn itg_err(&self) -> bool
Indicates data integrity error, that is, internal data integrity check has failed.
Sourcepub const fn set_itg_err(&mut self, val: bool)
pub const fn set_itg_err(&mut self, val: bool)
Indicates data integrity error, that is, internal data integrity check has failed.
Sourcepub const fn flt_err(&self) -> bool
pub const fn flt_err(&self) -> bool
Indicates hardware fault error; an attempt to change the value of an internal register.
Sourcepub const fn set_flt_err(&mut self, val: bool)
pub const fn set_flt_err(&mut self, val: bool)
Indicates hardware fault error; an attempt to change the value of an internal register.
Sourcepub const fn prng_err(&self) -> bool
pub const fn prng_err(&self) -> bool
Indicates user read of PRNG_DATOUT when STATUS[PRNG_RDY] is 0.
Sourcepub const fn set_prng_err(&mut self, val: bool)
pub const fn set_prng_err(&mut self, val: bool)
Indicates user read of PRNG_DATOUT when STATUS[PRNG_RDY] is 0.
Sourcepub const fn set_err_lvl(&mut self, val: u8)
pub const fn set_err_lvl(&mut self, val: u8)
Indicates the triggered error level: 0, 1 ,2.
Sourcepub const fn dtrng_err(&self) -> bool
pub const fn dtrng_err(&self) -> bool
TRNG unable to gather entropy with the current configuration
Sourcepub const fn set_dtrng_err(&mut self, val: bool)
pub const fn set_dtrng_err(&mut self, val: bool)
TRNG unable to gather entropy with the current configuration